emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/realgud 807c066 128/140: Initialize more debuggers with


From: Rocky Bernstein
Subject: [elpa] externals/realgud 807c066 128/140: Initialize more debuggers with breakpoint buffer information
Date: Sat, 25 May 2019 19:35:49 -0400 (EDT)

branch: externals/realgud
commit 807c0665634599c9c6f166f0f7177ccb2ca0f109
Author: rocky <address@hidden>
Commit: rocky <address@hidden>

    Initialize more debuggers with breakpoint buffer information
---
 realgud/common/cmds.el            |  4 ++--
 realgud/debugger/bashdb/init.el   | 23 +++++++++++++-----
 realgud/debugger/kshdb/init.el    | 28 +++++++++++++++++-----
 realgud/debugger/trepan2/init.el  | 49 +++++++++++++++++++++++++++------------
 realgud/debugger/trepan3k/init.el | 15 ++++++------
 realgud/debugger/zshdb/init.el    | 23 +++++++++++++-----
 realgud/lang/posix-shell.el       | 35 +++++++++++++++++++++++++++-
 realgud/lang/python.el            |  2 +-
 8 files changed, 135 insertions(+), 44 deletions(-)

diff --git a/realgud/common/cmds.el b/realgud/common/cmds.el
index cc589e7..b8ec55a 100644
--- a/realgud/common/cmds.el
+++ b/realgud/common/cmds.el
@@ -103,7 +103,7 @@ with other motion initiated by debugger messages."
     (puthash "finish"            "finish" hash)
     (puthash "frame"             "frame %p" hash)
     (puthash "help"              "help" hash)
-    (puthash "info-breakpoints"  "info break" hash)
+    (puthash "info-breakpoints"  "info breakpoints" hash)
     (puthash "jump"              "jump %l" hash)
     (puthash "kill"              "kill" hash)
     (puthash "next"              "next %p" hash)
@@ -237,7 +237,7 @@ example in a completing read."
     ;; Also note that lldb breakpoint numbers can be dotted like
     ;; 5.1.
     (mapcar (lambda (num) (format "%s" num))
-           (remove-duplicates
+           (cl-remove-duplicates
             (mapcar (lambda(loc) (realgud-loc-num loc))
                     (realgud-cmdbuf-info-bp-list realgud-cmdbuf-info))))))
 
diff --git a/realgud/debugger/bashdb/init.el b/realgud/debugger/bashdb/init.el
index e527b2d..06dc285 100644
--- a/realgud/debugger/bashdb/init.el
+++ b/realgud/debugger/bashdb/init.el
@@ -1,4 +1,4 @@
-;; Copyright (C) 2015-2017 Free Software Foundation, Inc
+;; Copyright (C) 2015-2017, 2019 Free Software Foundation, Inc
 
 ;; Author: Rocky Bernstein <address@hidden>
 
@@ -84,6 +84,11 @@ realgud-loc-pat struct")
 (setf (gethash "debugger-backtrace" realgud:bashdb-pat-hash)
       realgud:POSIX-debugger-backtrace-pat)
 
+;; FIXME breakpoints aren't locations. It should be a different structure
+;; realgud-loc that describes a zshdb "info breakpoints" line.
+(setf (gethash "debugger-breakpoint" realgud:bashdb-pat-hash)
+      realgud:POSIX-debugger-breakpoint-pat)
+
 ;; realgud-loc-pat for a termination message.
 (setf (gethash "termination" realgud:bashdb-pat-hash)
        "^bashdb: That's all, folks...\n")
@@ -91,6 +96,9 @@ realgud-loc-pat struct")
 (setf (gethash "font-lock-keywords" realgud:bashdb-pat-hash)
       realgud:POSIX-debugger-font-lock-keywords)
 
+(setf (gethash "font-lock-breakpoint-keywords" realgud:bashdb-pat-hash)
+      realgud:POSIX-debugger-font-lock-breakpoint-keywords)
+
 (setf (gethash "bashdb" realgud-pat-hash) realgud:bashdb-pat-hash)
 
 (defvar realgud:bashdb-command-hash (make-hash-table :test 'equal)
@@ -99,12 +107,15 @@ realgud-loc-pat struct")
 
 (setf (gethash "bashdb" realgud-command-hash) realgud:bashdb-command-hash)
 
-(setf (gethash "clear"  realgud:bashdb-command-hash) "clear %l")
-(setf (gethash "eval"   realgud:bashdb-command-hash) "eval %s")
-(setf (gethash "quit"   realgud:bashdb-command-hash) "quit")
-(setf (gethash "until"  realgud:bashdb-command-hash) "continue %l")
+(setf (gethash "clear"            realgud:bashdb-command-hash) "clear %l")
+(setf (gethash "eval"             realgud:bashdb-command-hash) "eval %s")
+(setf (gethash "info-breakpoints" realgud:bashdb-command-hash) "info 
breakpoints")
+(setf (gethash "quit"             realgud:bashdb-command-hash) "quit")
+(setf (gethash "until"            realgud:bashdb-command-hash) "continue %l")
 
 ;; Unsupported features:
-(setf (gethash "jump"  realgud:bashdb-command-hash) "*not-implemented*")
+(setf (gethash "break-fn"   realgud:bashdb-command-hash) "*not-implemented*")
+(setf (gethash "finish"     realgud:bashdb-command-hash) "*not-implemented*")
+(setf (gethash "jump"       realgud:bashdb-command-hash) "*not-implemented*")
 
 (provide-me "realgud:bashdb-")
diff --git a/realgud/debugger/kshdb/init.el b/realgud/debugger/kshdb/init.el
index 238eaff..c6e2d0f 100644
--- a/realgud/debugger/kshdb/init.el
+++ b/realgud/debugger/kshdb/init.el
@@ -1,4 +1,4 @@
-;; Copyright (C) 2010-2011, 2016-2017 Free Software Foundation, Inc
+;; Copyright (C) 2010-2011, 2016-2017, 2019 Free Software Foundation, Inc
 
 ;; Author: Rocky Bernstein <address@hidden>
 
@@ -79,13 +79,26 @@ realgud-loc-pat struct")
 (setf (gethash "debugger-backtrace" realgud:kshdb-pat-hash)
       realgud:POSIX-debugger-backtrace-pat)
 
+;; FIXME breakpoints aren't locations. It should be a different structure
+;; realgud-loc that describes a zshdb "info breakpoints" line.
+(setf (gethash "debugger-breakpoint" realgud:kshdb-pat-hash)
+      realgud:POSIX-debugger-backtrace-pat)
+
 ;; Regular expression that for a termination message.
 (setf (gethash "termination" realgud:kshdb-pat-hash)
        "^kshdb: That's all, folks...\n")
 
+;; FIXME breakpoints aren't locations. It should be a different structure
+;; realgud-loc that describes a zshdb "info breakpoints" line.
+(setf (gethash "debugger-breakpoint" realgud:kshdb-pat-hash)
+      realgud:POSIX-debugger-breakpoint-pat)
+
 (setf (gethash "font-lock-keywords" realgud:kshdb-pat-hash)
       realgud:POSIX-debugger-font-lock-keywords)
 
+(setf (gethash "font-lock-breakpoint-keywords" realgud:kshdb-pat-hash)
+      realgud:POSIX-debugger-font-lock-breakpoint-keywords)
+
 (setf (gethash "kshdb" realgud-pat-hash) realgud:kshdb-pat-hash)
 
 (defvar realgud:kshdb-command-hash (make-hash-table :test 'equal)
@@ -97,12 +110,15 @@ realgud-loc-pat struct")
 ;; (setf (gethash "quit" realgud:kshdb-command-hash) "quit!")
 
 
-(setf (gethash "clear"  realgud:kshdb-command-hash) "clear %l")
-(setf (gethash "eval"   realgud:kshdb-command-hash) "eval %s")
-(setf (gethash "quit"   realgud:kshdb-command-hash) "quit")
-(setf (gethash "until"  realgud:kshdb-command-hash) "continue %l")
+(setf (gethash "clear"            realgud:kshdb-command-hash) "clear %l")
+(setf (gethash "eval"             realgud:kshdb-command-hash) "eval %s")
+(setf (gethash "info-breakpoints" realgud:kshdb-command-hash) "info 
breakpoints")
+(setf (gethash "quit"             realgud:kshdb-command-hash) "quit")
+(setf (gethash "until"            realgud:kshdb-command-hash) "continue %l")
 
 ;; Unsupported features:
-(setf (gethash "jump"  realgud:kshdb-command-hash) "*not-implemented*")
+(setf (gethash "jump"   realgud:kshdb-command-hash) "*not-implemented*")
+(setf (gethash "finish" realgud:kshdb-command-hash) "*not-implemented*")
+(setf (gethash "jump"   realgud:kshdb-command-hash) "*not-implemented*")
 
 (provide-me "realgud:kshdb-")
diff --git a/realgud/debugger/trepan3k/init.el 
b/realgud/debugger/trepan3k/init.el
index 248a109..3474410 100644
--- a/realgud/debugger/trepan3k/init.el
+++ b/realgud/debugger/trepan3k/init.el
@@ -40,7 +40,7 @@ realgud-loc-pat struct")
 ;; before a command prompt.
 ;;
 ;; For example:
-;;   (/usr/bin/zonetab2pot.py:15): <module>
+;;   (/usr/bin/zonetab2pot.py:15 @3): <module>
 ;;   (/usr/bin/zonetab2pot.py:15 remapped <string>): <module>
 ;; or MS Windows:
 ;;   (c:\\mydirectory\\gcd.py:10): <module>
@@ -55,7 +55,7 @@ realgud-loc-pat struct")
 (setf (gethash "ignore-re-file-list" realgud:trepan3k-pat-hash)
       (list realgud-python-ignore-file-re))
 
-;; Regular expression that describes a trepan3k prompt.
+;; realgud-loc-pat that describes a trepan3k prompt.
 ;; Note: the prompt in nested debugging
 ;; For example:
 ;; (trepan3)
@@ -90,7 +90,7 @@ realgud-loc-pat struct")
 (setf (gethash "pytest-error" realgud:trepan3k-pat-hash)
       realgud-pytest-error-loc-pat)
 
-;;  Regular expression that describes location in a flake8 message
+;;  realgud-loc-pat that describes location in a flake8 message
 (setf (gethash "flake8-msg" realgud:trepan3k-pat-hash)
       realgud-flake8-msg-loc-pat)
 
@@ -130,10 +130,11 @@ realgud-loc-pat struct")
   "Hash key is command name like 'shell' and the value is
   the trepan3k command to use, like 'python'")
 
-(setf (gethash "eval"   realgud:trepan3k-command-hash) "eval %s")
-(setf (gethash "pprint" realgud:trepan3k-command-hash) "pp %s")
-(setf (gethash "shell"  realgud:trepan3k-command-hash) "python")
-(setf (gethash "until"  realgud:trepan3k-command-hash) "continue %l")
+(setf (gethash "eval"             realgud:trepan3k-command-hash) "eval %s")
+(setf (gethash "info-breakpoints" realgud:trepan3k-command-hash) "info break")
+(setf (gethash "pprint"           realgud:trepan3k-command-hash) "pp %s")
+(setf (gethash "shell"            realgud:trepan3k-command-hash) "python")
+(setf (gethash "until"            realgud:trepan3k-command-hash) "continue %l")
 
 ;; If your version of trepan3k doesn't support "quit!",
 ;; get a more recent version of trepan3k
diff --git a/realgud/debugger/zshdb/init.el b/realgud/debugger/zshdb/init.el
index 3fac621..a186fd3 100644
--- a/realgud/debugger/zshdb/init.el
+++ b/realgud/debugger/zshdb/init.el
@@ -1,4 +1,4 @@
-;; Copyright (C) 2015-2016 Free Software Foundation, Inc
+;; Copyright (C) 2015-2016, 2019 Free Software Foundation, Inc
 
 ;; Author: Rocky Bernstein <address@hidden>
 
@@ -80,6 +80,11 @@ realgud-loc-pat struct")
 (setf (gethash "debugger-backtrace" realgud:zshdb-pat-hash)
       realgud:POSIX-debugger-backtrace-pat)
 
+;; FIXME breakpoints aren't locations. It should be a different structure
+;; realgud-loc that describes a zshdb "info breakpoints" line.
+(setf (gethash "debugger-breakpoint" realgud:zshdb-pat-hash)
+      realgud:POSIX-debugger-breakpoint-pat)
+
 ;; realgud-loc-pat that for a termination message.
 (setf (gethash "termination" realgud:zshdb-pat-hash)
        "^zshdb: That's all, folks...\n")
@@ -87,6 +92,9 @@ realgud-loc-pat struct")
 (setf (gethash "font-lock-keywords" realgud:zshdb-pat-hash)
       realgud:POSIX-debugger-font-lock-keywords)
 
+(setf (gethash "font-lock-breakpoint-keywords" realgud:zshdb-pat-hash)
+      realgud:POSIX-debugger-font-lock-breakpoint-keywords)
+
 (setf (gethash "zshdb" realgud-pat-hash) realgud:zshdb-pat-hash)
 
 (defvar realgud:zshdb-command-hash (make-hash-table :test 'equal)
@@ -95,12 +103,15 @@ realgud-loc-pat struct")
 
 (setf (gethash "zshdb"  realgud-command-hash) realgud:zshdb-command-hash)
 
-(setf (gethash "clear"  realgud:zshdb-command-hash) "clear %l")
-(setf (gethash "eval"   realgud:zshdb-command-hash) "eval %s")
-(setf (gethash "quit"   realgud:zshdb-command-hash) "quit")
-(setf (gethash "until"  realgud:zshdb-command-hash) "continue %l")
+(setf (gethash "clear"            realgud:zshdb-command-hash) "clear %l")
+(setf (gethash "eval"             realgud:zshdb-command-hash) "eval %s")
+(setf (gethash "info-breakpoints" realgud:zshdb-command-hash) "info 
breakpoints")
+(setf (gethash "quit"             realgud:zshdb-command-hash) "quit")
+(setf (gethash "until"            realgud:zshdb-command-hash) "continue %l")
 
 ;; Unsupported features:
-(setf (gethash "jump"  realgud:zshdb-command-hash) "*not-implemented*")
+(setf (gethash "break-fn" realgud:zshdb-command-hash) "*not-implemented*")
+(setf (gethash "finish"   realgud:zshdb-command-hash) "*not-implemented*")
+(setf (gethash "jump"     realgud:zshdb-command-hash) "*not-implemented*")
 
 (provide-me "realgud:zshdb-")
diff --git a/realgud/lang/python.el b/realgud/lang/python.el
index a2ddbfd..f7ff77e 100644
--- a/realgud/lang/python.el
+++ b/realgud/lang/python.el
@@ -94,7 +94,7 @@ traceback) line."  )
    ))
 
 ;; FIXME breakpoints aren't locations. It should be a different structure
-;; Regular expression that describes a trepan2/3k backtrace line.
+;; realgud-loc that describes a trepan2/3k "info breakpoints" line.
 ;; For example:
 ;; 1   breakpoint    keep y   at 
/home/rocky/.pyenv/versions/3.7.2/lib/python3.7/importlib/_bootstrap.py:1019
 ;; 2   breakpoint    keep y   at 
/home/rocky/.pyenv/versions/3.7.2/lib/python3.7/importlib/_bootstrap.py:1023



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/realgud/debugger/trepan2/init.el b/realgud/debugger/trepan2/init.el
index ecc206e..9217ae1 100644
--- a/realgud/debugger/trepan2/init.el
+++ b/realgud/debugger/trepan2/init.el
@@ -1,4 +1,4 @@
-;; Copyright (C) 2010-2012, 2014-2017 Free Software Foundation, Inc
+;; Copyright (C) 2010-2012, 2014-2017, 2019 Free Software Foundation, Inc
 
 ;; Author: Rocky Bernstein <address@hidden>
 
@@ -7,6 +7,14 @@
 ;; the Free Software Foundation, either version 3 of the License, or
 ;; (at your option) any later version.
 
+;; This program is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+
+;; You should have received a copy of the GNU General Public License
+;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
 ;; trepan2: Python 2.5 - 2.7; for 3.0+ see trepan3k
 
 (eval-when-compile (require 'cl-lib))   ;For setf.
@@ -30,7 +38,7 @@ realgud-loc-pat struct")
 
 (setf (gethash "loc-callback-fn" realgud:trepan2-pat-hash) 
'realgud:trepan2-loc-fn-callback)
 
 ;; Regular expression that describes a trepan2 location generally shown
 ;; before a command prompt.
 ;;
 ;; For example:
@@ -49,7 +57,7 @@ realgud-loc-pat struct")
 (setf (gethash "ignore-re-file-list" realgud:trepan2-pat-hash)
       (list realgud-python-ignore-file-re))
 
 ;; Regular expression that describes a trepan2 prompt.
 ;; Note: the prompt in nested debugging
 ;; For example:
 ;; (trepan2)
@@ -59,7 +67,7 @@ realgud-loc-pat struct")
        :regexp   "^(+trepan2)+ "
        ))
 
 ;; Regular expression that describes a trepan2 backtrace line.
 ;; For example:
 ;; ->0 get_distribution(dist='trepan==0.3.9')
 ;;     called from file '/python2.7/dist-packages/pkg_res.py' at line 341
@@ -70,54 +78,65 @@ realgud-loc-pat struct")
 (setf (gethash "debugger-backtrace" realgud:trepan2-pat-hash)
       realgud:python-trepan-backtrace-pat)
 
-;;  Regular expression that describes a Python backtrace line.
+;; realgud-loc-pat that describes a line a Python "info break" line.
+;; For example:
+;; 1   breakpoint    keep y   at /usr/local/bin/trepan2k:7
+(setf (gethash "debugger-breakpoint" realgud:trepan2-pat-hash)
+      realgud-python-breakpoint-pat)
+
+;;  realgud-loc-pat that describes a Python backtrace line.
 (setf (gethash "lang-backtrace" realgud:trepan2-pat-hash)
       realgud-python-backtrace-loc-pat)
 
 ;;  Regular expression that describes location in a pytest error
 (setf (gethash "pytest-error" realgud:trepan2-pat-hash)
       realgud-pytest-error-loc-pat)
 
 ;;  Regular expression that describes location in a flake8 message
 (setf (gethash "flake8-msg" realgud:trepan2-pat-hash)
       realgud-flake8-msg-loc-pat)
 
 ;;  Regular expression that describes a "breakpoint set" line
 (setf (gethash "brkpt-set" realgud:trepan2-pat-hash)
       realgud:python-trepan-brkpt-set-pat)
 
 ;;  Regular expression that describes a "delete breakpoint" line
 (setf (gethash "brkpt-del" realgud:trepan2-pat-hash)
       realgud:python-trepan-brkpt-del-pat)
 
-;; Regular expression that describes a debugger "disable" (breakpoint) 
response.
+;; realgud-loc-pat that describes a debugger "disable" (breakpoint) response.
 ;; For example:
 ;;   Breakpoint 4 disabled.
 (setf (gethash "brkpt-disable" realgud:trepan2-pat-hash)
       realgud:python-trepan-brkpt-disable-pat)
 
 ;; Regular expression that describes a debugger "enable" (breakpoint) response.
 ;; For example:
 ;;   Breakpoint 4 enabled.
 (setf (gethash "brkpt-enable" realgud:trepan2-pat-hash)
       realgud:python-trepan-brkpt-disable-pat)
 
-;; Regular expression for a termination message.
+;; realgud-loc-pat for a termination message.
 (setf (gethash "termination" realgud:trepan2-pat-hash)
       "^trepan2: That's all, folks...\n")
 
 (setf (gethash "font-lock-keywords" realgud:trepan2-pat-hash)
       realgud:python-debugger-font-lock-keywords)
 
+(setf (gethash "font-lock-breakpoint-keywords" realgud:trepan2-pat-hash)
+      realgud:python-debugger-font-lock-breakpoint-keywords)
+
 (setf (gethash "trepan2" realgud-pat-hash) realgud:trepan2-pat-hash)
 
 (defvar realgud:trepan2-command-hash (make-hash-table :test 'equal)
   "Hash key is command name like 'shell' and the value is
   the trepan2 command to use, like 'python'")
 
-(setf (gethash "eval"  realgud:trepan2-command-hash) "eval %s")
-(setf (gethash "shell" realgud:trepan2-command-hash) "python")
-(setf (gethash "until" realgud:trepan2-command-hash) "continue %l")
+(setf (gethash "eval"             realgud:trepan2-command-hash) "eval %s")
+(setf (gethash "pprint"           realgud:trepan2-command-hash) "pp %s")
+(setf (gethash "info-breakpoints" realgud:trepan2-command-hash) "info break")
+(setf (gethash "shell"            realgud:trepan2-command-hash) "python")
+(setf (gethash "until"            realgud:trepan2-command-hash) "continue %l")
 
 ;; If your version of trepan2 doesn't support "quit!",
 ;; get a more recent version of trepan2
@@ -30,7 +38,7 @@ realgud-loc-pat struct")
'realgud:trepan2-loc-fn-callback)
 
-;; Regular expression that describes a trepan2 location generally shown
+;; realgud-loc-pat that describes a trepan2 location generally shown
 ;; before a command prompt.
 ;;
@@ -49,7 +57,7 @@ realgud-loc-pat struct")
       (list realgud-python-ignore-file-re))
 
-;; Regular expression that describes a trepan2 prompt.
+;; realgud-loc-pat that describes a trepan2 prompt.
 ;; Note: the prompt in nested debugging
 ;; For example:
@@ -59,7 +67,7 @@ realgud-loc-pat struct")
        ))
 
-;; Regular expression that describes a trepan2 backtrace line.
+;; realgud-loc-pat that describes a trepan2 backtrace line.
 ;; For example:
 ;; ->0 get_distribution(dist='trepan==0.3.9')
@@ -70,54 +78,65 @@ realgud-loc-pat struct")
       realgud-python-backtrace-loc-pat)
 
-;;  Regular expression that describes location in a pytest error
+;;  realgud-loc-pat expression that describes location in a pytest error
 (setf (gethash "pytest-error" realgud:trepan2-pat-hash)
       realgud-pytest-error-loc-pat)
@@ -70,54 +78,65 @@ realgud-loc-pat struct")
       realgud-pytest-error-loc-pat)
 
-;;  Regular expression that describes location in a flake8 message
+;;  realgud-loc-pat that describes location in a flake8 message
 (setf (gethash "flake8-msg" realgud:trepan2-pat-hash)
       realgud-flake8-msg-loc-pat)
@@ -70,54 +78,65 @@ realgud-loc-pat struct")
       realgud-flake8-msg-loc-pat)
 
-;;  Regular expression that describes a "breakpoint set" line
+;;  realgud-loc-pat that describes a "breakpoint set" line
 (setf (gethash "brkpt-set" realgud:trepan2-pat-hash)
       realgud:python-trepan-brkpt-set-pat)
@@ -70,54 +78,65 @@ realgud-loc-pat struct")
       realgud:python-trepan-brkpt-set-pat)
 
-;;  Regular expression that describes a "delete breakpoint" line
+;;  realgud-loc-pat that describes a "delete breakpoint" line
 (setf (gethash "brkpt-del" realgud:trepan2-pat-hash)
       realgud:python-trepan-brkpt-del-pat)
@@ -70,54 +78,65 @@ realgud-loc-pat struct")
       realgud:python-trepan-brkpt-disable-pat)
 
-;; Regular expression that describes a debugger "enable" (breakpoint) response.
+;; realgud-loc-pat that describes a debugger "enable" (breakpoint) response.
 ;; For example:
 ;;   Breakpoint 4 enabled.
diff --git a/realgud/lang/posix-shell.el b/realgud/lang/posix-shell.el
index 1ef2313..a1787cc 100644
--- a/realgud/lang/posix-shell.el
+++ b/realgud/lang/posix-shell.el
@@ -68,7 +68,7 @@ traceback) line."  )
       "A realgud-loc-pat struct that describes a POSIX shell debugger
       location line.")
 
 ;; Regular expression that describes a debugger "backtrace" command line.
 ;; For example:
 ;;   ->0 in file `/etc/apparmor/fns' at line 24
 ;;   ##1 /etc/apparmor/fns called from file `/etc/init.d/apparmor' at line 35
@@ -87,6 +87,22 @@ traceback) line."  )
   "A realgud-loc-pat struct that describes a Python trepan
       backtrace location line." )
 
+;; FIXME breakpoints aren't locations. It should be a different structure
+;; realgud-loc that describes a bashdb/zshdb/kshdb "info breakpoints" line.
+;; For example:
+;; 1   breakpoint keep y   /Users/rocky/.bashrc:17
+;; 2   breakpoint keep y   /Users/rocky/.bashrc:18
+(defconst realgud:POSIX-debugger-breakpoint-pat
+  (make-realgud-loc-pat
+   :regexp (format "^%s[ \t]+\\(breakpoint\\)[ \t]+\\(keep\\|del\\)[ 
\t]+\\([yn]\\)[ \t]+\\(.+\\):%s"
+                  realgud:regexp-captured-num realgud:regexp-captured-num)
+   :num 1
+   :text-group 2  ;; misnamed Is "breakpoint" or "watchpoint"
+   :string 3      ;; misnamed. Is "keep" or "del"
+   :file-group 5
+   :line-group 6)
+  "A realgud-loc-pat struct that describes a bashdb/zshdb/kshdb breakpoint."  )
+
 ;;  Regular expression that describes a "breakpoint set" line
 (defconst realgud:POSIX-debugger-brkpt-set-pat
   (make-realgud-loc-pat
@@ -147,4 +163,21 @@ traceback) line."  )
     ;;  (0 trepan-frames-current-frame-face append))
     ))
 
+(defconst realgud:POSIX-debugger-font-lock-breakpoint-keywords
+  '(
+    ;; The breakpoint number, type and disposition
+    ;; 1   breakpoint    keep y   /Users/rocky/.bashrc:6
+    ;; ^   ^^^^^^^^^^    ^^^^
+    ("^\\([0-9]+\\)[ \t]+\\(breakpoint\\)[ \t]+\\(keep\\|del\\)"
+     (1 realgud-breakpoint-number-face)
+     (2 font-lock-function-name-face nil t)     ; t means optional.
+     (3 font-lock-function-name-face nil t))     ; t means optional.
+
+    ;; 1   breakpoint    keep y   /Users/rocky/.bashrc:6
+    ;;                            ^^^^^^^^^^^^^^^^^^^^^^
+    ("[ \t]+\\(.+*\\):\\([0-9]+\\)"
+     (1 realgud-file-name-face)
+     (1 realgud-line-number-face))
+    ))
+
 (provide-me "realgud-lang-")
@@ -68,7 +68,7 @@ traceback) line."  )
       location line.")
 
-;; Regular expression that describes a debugger "backtrace" command line.
+;; realgud-loc that describes a debugger "backtrace" command line.
 ;; For example:
 ;;   ->0 in file `/etc/apparmor/fns' at line 24